<?php

namespace Newgenpower\Project\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Newgenpower\Project\Models\Feature;

class FeaturePolicy
{

    /**
     * Determine if the given user can view the feature.
     *
     * @param UserPolicyInterface $authUser
     * @param Feature $feature
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Feature $feature)
    {
        if ($authUser->canDo('project.feature.view') && $authUser->isAdmin()) {
            return true;
        }

        return $feature->user_id == user_id() && $feature->user_type == user_type();
    }

    /**
     * Determine if the given user can create a feature.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('project.feature.create');
    }

    /**
     * Determine if the given user can update the given feature.
     *
     * @param UserPolicyInterface $authUser
     * @param Feature $feature
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Feature $feature)
    {
        if ($authUser->canDo('project.feature.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $feature->user_id == user_id() && $feature->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given feature.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Feature $feature)
    {
        return $feature->user_id == user_id() && $feature->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given feature.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Feature $feature)
    {
        if ($authUser->canDo('project.feature.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given feature.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Feature $feature)
    {
        if ($authUser->canDo('project.feature.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
