<?php

namespace Newgenpower\Project\Providers;

use Illuminate\Support\ServiceProvider;
use Newgenpower\Project\Projects;

class ProjectServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'project');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'project');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Newgenpower\Project\Providers\AuthServiceProvider::class);
        $this->app->register(\Newgenpower\Project\Providers\RouteServiceProvider::class);
        // $this->app->register(\Newgenpower\Project\Providers\EventServiceProvider::class);
        // $this->app->register(\Newgenpower\Project\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('newgenpower.project', function($app)
        {
            return $this->app->make(Projects::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind Project to repository
        $this->app->bind(
            'Newgenpower\Project\Interfaces\ProjectRepositoryInterface',
            \Newgenpower\Project\Repositories\Eloquent\ProjectRepository::class
        );        // Bind Feature to repository
        $this->app->bind(
            'Newgenpower\Project\Interfaces\FeatureRepositoryInterface',
            \Newgenpower\Project\Repositories\Eloquent\FeatureRepository::class
        );
    }


    /**
     * Merges user's and project's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'newgenpower.project'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Newgenpower\Project\Commands\Project::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['newgenpower.project'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('newgenpower/project.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/project')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/project')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
